==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutPropertiesSpecificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property canary
 * @property expeditedRollout
 * @property highTraffic
 * @property lowTraffic
 * @property mediumTraffic
 * @property providerRegistration
 * @property resourceTypeRegistrations
 * @property restOfTheWorldGroupOne
 * @property restOfTheWorldGroupTwo
 */
public data class DefaultRolloutPropertiesSpecificationArgs(
    public val canary: Output<DefaultRolloutSpecificationCanaryArgs>? = null,
    public val expeditedRollout: Output<DefaultRolloutSpecificationExpeditedRolloutArgs>? = null,
    public val highTraffic: Output<DefaultRolloutSpecificationHighTrafficArgs>? = null,
    public val lowTraffic: Output<DefaultRolloutSpecificationLowTrafficArgs>? = null,
    public val mediumTraffic: Output<DefaultRolloutSpecificationMediumTrafficArgs>? = null,
    public val providerRegistration: Output<DefaultRolloutSpecificationProviderRegistrationArgs>? =
        null,
    public val resourceTypeRegistrations: Output<List<ResourceTypeRegistrationArgs>>? = null,
    public val restOfTheWorldGroupOne: Output<DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs>? =
        null,
    public val restOfTheWorldGroupTwo: Output<DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs.builder()
            .canary(canary?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .expeditedRollout(expeditedRollout?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .highTraffic(highTraffic?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .lowTraffic(lowTraffic?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mediumTraffic(mediumTraffic?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .providerRegistration(
                providerRegistration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .resourceTypeRegistrations(
                resourceTypeRegistrations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .restOfTheWorldGroupOne(
                restOfTheWorldGroupOne?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .restOfTheWorldGroupTwo(
                restOfTheWorldGroupTwo?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DefaultRolloutPropertiesSpecificationArgs].
 */
@PulumiTagMarker
public class DefaultRolloutPropertiesSpecificationArgsBuilder internal constructor() {
    private var canary: Output<DefaultRolloutSpecificationCanaryArgs>? = null

    private var expeditedRollout: Output<DefaultRolloutSpecificationExpeditedRolloutArgs>? = null

    private var highTraffic: Output<DefaultRolloutSpecificationHighTrafficArgs>? = null

    private var lowTraffic: Output<DefaultRolloutSpecificationLowTrafficArgs>? = null

    private var mediumTraffic: Output<DefaultRolloutSpecificationMediumTrafficArgs>? = null

    private var providerRegistration: Output<DefaultRolloutSpecificationProviderRegistrationArgs>? =
        null

    private var resourceTypeRegistrations: Output<List<ResourceTypeRegistrationArgs>>? = null

    private var restOfTheWorldGroupOne: Output<DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs>? =
        null

    private var restOfTheWorldGroupTwo: Output<DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("huvruhxolhyeaujd")
    public suspend fun canary(`value`: Output<DefaultRolloutSpecificationCanaryArgs>) {
        this.canary = value
    }

    /**
     * @param value
     */
    @JvmName("uhgdneirhrwlmjph")
    public suspend
    fun expeditedRollout(`value`: Output<DefaultRolloutSpecificationExpeditedRolloutArgs>) {
        this.expeditedRollout = value
    }

    /**
     * @param value
     */
    @JvmName("yfenypmuqigcqpge")
    public suspend fun highTraffic(`value`: Output<DefaultRolloutSpecificationHighTrafficArgs>) {
        this.highTraffic = value
    }

    /**
     * @param value
     */
    @JvmName("atgabjlbyrghjshh")
    public suspend fun lowTraffic(`value`: Output<DefaultRolloutSpecificationLowTrafficArgs>) {
        this.lowTraffic = value
    }

    /**
     * @param value
     */
    @JvmName("qbrbntgpkdxxnqrc")
    public suspend fun mediumTraffic(`value`: Output<DefaultRolloutSpecificationMediumTrafficArgs>) {
        this.mediumTraffic = value
    }

    /**
     * @param value
     */
    @JvmName("kicdllubewkqmneq")
    public suspend
    fun providerRegistration(`value`: Output<DefaultRolloutSpecificationProviderRegistrationArgs>) {
        this.providerRegistration = value
    }

    /**
     * @param value
     */
    @JvmName("hyulvsubsdahvdnn")
    public suspend
    fun resourceTypeRegistrations(`value`: Output<List<ResourceTypeRegistrationArgs>>) {
        this.resourceTypeRegistrations = value
    }

    @JvmName("oydqqtwwyeljmtig")
    public suspend fun resourceTypeRegistrations(
        vararg
        values: Output<ResourceTypeRegistrationArgs>,
    ) {
        this.resourceTypeRegistrations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ttjclxlphxfeyiqy")
    public suspend fun resourceTypeRegistrations(values: List<Output<ResourceTypeRegistrationArgs>>) {
        this.resourceTypeRegistrations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qnmoaosddtdvrjum")
    public suspend
    fun restOfTheWorldGroupOne(`value`: Output<DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs>) {
        this.restOfTheWorldGroupOne = value
    }

    /**
     * @param value
     */
    @JvmName("amnkndsieaqpwjra")
    public suspend
    fun restOfTheWorldGroupTwo(`value`: Output<DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs>) {
        this.restOfTheWorldGroupTwo = value
    }

    /**
     * @param value
     */
    @JvmName("lutbvcebrstwomna")
    public suspend fun canary(`value`: DefaultRolloutSpecificationCanaryArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.canary = mapped
    }

    /**
     * @param argument
     */
    @JvmName("prtanmfbeuavvmcy")
    public suspend
    fun canary(argument: suspend DefaultRolloutSpecificationCanaryArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationCanaryArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.canary = mapped
    }

    /**
     * @param value
     */
    @JvmName("ghbsqhtnlmdphpcx")
    public suspend fun expeditedRollout(`value`: DefaultRolloutSpecificationExpeditedRolloutArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expeditedRollout = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ytyhpvkvyutxptsd")
    public suspend
    fun expeditedRollout(argument: suspend DefaultRolloutSpecificationExpeditedRolloutArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationExpeditedRolloutArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.expeditedRollout = mapped
    }

    /**
     * @param value
     */
    @JvmName("uoqrslykhckvlpfp")
    public suspend fun highTraffic(`value`: DefaultRolloutSpecificationHighTrafficArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.highTraffic = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ywimylmtmwbmmdfp")
    public suspend
    fun highTraffic(argument: suspend DefaultRolloutSpecificationHighTrafficArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationHighTrafficArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.highTraffic = mapped
    }

    /**
     * @param value
     */
    @JvmName("jqurjgackcdxlpxo")
    public suspend fun lowTraffic(`value`: DefaultRolloutSpecificationLowTrafficArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lowTraffic = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tnfjsjerwgxcvibf")
    public suspend
    fun lowTraffic(argument: suspend DefaultRolloutSpecificationLowTrafficArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationLowTrafficArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.lowTraffic = mapped
    }

    /**
     * @param value
     */
    @JvmName("xsutavsrnnvwuwek")
    public suspend fun mediumTraffic(`value`: DefaultRolloutSpecificationMediumTrafficArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mediumTraffic = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ttgdvpkqufbjxfex")
    public suspend
    fun mediumTraffic(argument: suspend DefaultRolloutSpecificationMediumTrafficArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationMediumTrafficArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.mediumTraffic = mapped
    }

    /**
     * @param value
     */
    @JvmName("uwittslbudxufvju")
    public suspend
    fun providerRegistration(`value`: DefaultRolloutSpecificationProviderRegistrationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerRegistration = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vxebmobqiwvwkubv")
    public suspend
    fun providerRegistration(argument: suspend DefaultRolloutSpecificationProviderRegistrationArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationProviderRegistrationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.providerRegistration = mapped
    }

    /**
     * @param value
     */
    @JvmName("lyxelxmgfcnghqdo")
    public suspend fun resourceTypeRegistrations(`value`: List<ResourceTypeRegistrationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nscktxdjjlaxuvit")
    public suspend
    fun resourceTypeRegistrations(argument: List<suspend ResourceTypeRegistrationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceTypeRegistrationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ftvmsxxfvshxxctg")
    public suspend fun resourceTypeRegistrations(
        vararg
        argument: suspend ResourceTypeRegistrationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceTypeRegistrationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("oqbtjldshkimxjnt")
    public suspend
    fun resourceTypeRegistrations(argument: suspend ResourceTypeRegistrationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceTypeRegistrationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param values
     */
    @JvmName("fgikpsdwigmmbyfb")
    public suspend fun resourceTypeRegistrations(vararg values: ResourceTypeRegistrationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param value
     */
    @JvmName("pwmpbandrjaoulgv")
    public suspend
    fun restOfTheWorldGroupOne(`value`: DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.restOfTheWorldGroupOne = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yjuhltkphgduqjoc")
    public suspend
    fun restOfTheWorldGroupOne(argument: suspend DefaultRolloutSpecificationRestOfTheWorldGroupOneArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationRestOfTheWorldGroupOneArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.restOfTheWorldGroupOne = mapped
    }

    /**
     * @param value
     */
    @JvmName("ndbacoubdoxjffhe")
    public suspend
    fun restOfTheWorldGroupTwo(`value`: DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.restOfTheWorldGroupTwo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("crcrkdnuuoefuhnc")
    public suspend
    fun restOfTheWorldGroupTwo(argument: suspend DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.restOfTheWorldGroupTwo = mapped
    }

    internal fun build(): DefaultRolloutPropertiesSpecificationArgs =
        DefaultRolloutPropertiesSpecificationArgs(
            canary = canary,
            expeditedRollout = expeditedRollout,
            highTraffic = highTraffic,
            lowTraffic = lowTraffic,
            mediumTraffic = mediumTraffic,
            providerRegistration = providerRegistration,
            resourceTypeRegistrations = resourceTypeRegistrations,
            restOfTheWorldGroupOne = restOfTheWorldGroupOne,
            restOfTheWorldGroupTwo = restOfTheWorldGroupTwo,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutPropertiesSpecificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property canary
 * @property expeditedRollout
 * @property highTraffic
 * @property lowTraffic
 * @property mediumTraffic
 * @property providerRegistration
 * @property resourceTypeRegistrations
 * @property restOfTheWorldGroupOne
 * @property restOfTheWorldGroupTwo
 */
public data class DefaultRolloutPropertiesSpecificationArgs(
    public val canary: Output<DefaultRolloutSpecificationCanaryArgs>? = null,
    public val expeditedRollout: Output<DefaultRolloutSpecificationExpeditedRolloutArgs>? = null,
    public val highTraffic: Output<DefaultRolloutSpecificationHighTrafficArgs>? = null,
    public val lowTraffic: Output<DefaultRolloutSpecificationLowTrafficArgs>? = null,
    public val mediumTraffic: Output<DefaultRolloutSpecificationMediumTrafficArgs>? = null,
    public val providerRegistration: Output<DefaultRolloutSpecificationProviderRegistrationArgs>? =
        null,
    public val resourceTypeRegistrations: Output<List<ResourceTypeRegistrationArgs>>? = null,
    public val restOfTheWorldGroupOne: Output<DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs>? =
        null,
    public val restOfTheWorldGroupTwo: Output<DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutPropertiesSpecificationArgs.builder()
            .canary(canary?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .expeditedRollout(expeditedRollout?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .highTraffic(highTraffic?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .lowTraffic(lowTraffic?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mediumTraffic(mediumTraffic?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .providerRegistration(
                providerRegistration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .resourceTypeRegistrations(
                resourceTypeRegistrations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .restOfTheWorldGroupOne(
                restOfTheWorldGroupOne?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .restOfTheWorldGroupTwo(
                restOfTheWorldGroupTwo?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [DefaultRolloutPropertiesSpecificationArgs].
 */
@PulumiTagMarker
public class DefaultRolloutPropertiesSpecificationArgsBuilder internal constructor() {
    private var canary: Output<DefaultRolloutSpecificationCanaryArgs>? = null

    private var expeditedRollout: Output<DefaultRolloutSpecificationExpeditedRolloutArgs>? = null

    private var highTraffic: Output<DefaultRolloutSpecificationHighTrafficArgs>? = null

    private var lowTraffic: Output<DefaultRolloutSpecificationLowTrafficArgs>? = null

    private var mediumTraffic: Output<DefaultRolloutSpecificationMediumTrafficArgs>? = null

    private var providerRegistration: Output<DefaultRolloutSpecificationProviderRegistrationArgs>? =
        null

    private var resourceTypeRegistrations: Output<List<ResourceTypeRegistrationArgs>>? = null

    private var restOfTheWorldGroupOne: Output<DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs>? =
        null

    private var restOfTheWorldGroupTwo: Output<DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("bfradyblxjgkfdys")
    public suspend fun canary(`value`: Output<DefaultRolloutSpecificationCanaryArgs>) {
        this.canary = value
    }

    /**
     * @param value
     */
    @JvmName("wsacvrkadeltqkoo")
    public suspend
    fun expeditedRollout(`value`: Output<DefaultRolloutSpecificationExpeditedRolloutArgs>) {
        this.expeditedRollout = value
    }

    /**
     * @param value
     */
    @JvmName("omqkulpqiqbbxouo")
    public suspend fun highTraffic(`value`: Output<DefaultRolloutSpecificationHighTrafficArgs>) {
        this.highTraffic = value
    }

    /**
     * @param value
     */
    @JvmName("rcgfiepluuiyymcw")
    public suspend fun lowTraffic(`value`: Output<DefaultRolloutSpecificationLowTrafficArgs>) {
        this.lowTraffic = value
    }

    /**
     * @param value
     */
    @JvmName("psugatmhrfwhyuvo")
    public suspend fun mediumTraffic(`value`: Output<DefaultRolloutSpecificationMediumTrafficArgs>) {
        this.mediumTraffic = value
    }

    /**
     * @param value
     */
    @JvmName("yjrohignbiuawrmj")
    public suspend
    fun providerRegistration(`value`: Output<DefaultRolloutSpecificationProviderRegistrationArgs>) {
        this.providerRegistration = value
    }

    /**
     * @param value
     */
    @JvmName("xnypmqivpumtpnmu")
    public suspend
    fun resourceTypeRegistrations(`value`: Output<List<ResourceTypeRegistrationArgs>>) {
        this.resourceTypeRegistrations = value
    }

    @JvmName("pqotnwdnloadjitx")
    public suspend fun resourceTypeRegistrations(
        vararg
        values: Output<ResourceTypeRegistrationArgs>,
    ) {
        this.resourceTypeRegistrations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("skcywfmyrogagcdl")
    public suspend fun resourceTypeRegistrations(values: List<Output<ResourceTypeRegistrationArgs>>) {
        this.resourceTypeRegistrations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("rbghdcapqlgmthen")
    public suspend
    fun restOfTheWorldGroupOne(`value`: Output<DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs>) {
        this.restOfTheWorldGroupOne = value
    }

    /**
     * @param value
     */
    @JvmName("dhphboqdqyoloohm")
    public suspend
    fun restOfTheWorldGroupTwo(`value`: Output<DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs>) {
        this.restOfTheWorldGroupTwo = value
    }

    /**
     * @param value
     */
    @JvmName("nvgommoijwfwuoeg")
    public suspend fun canary(`value`: DefaultRolloutSpecificationCanaryArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.canary = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rvfxlxkmcciwvnbb")
    public suspend
    fun canary(argument: suspend DefaultRolloutSpecificationCanaryArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationCanaryArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.canary = mapped
    }

    /**
     * @param value
     */
    @JvmName("aefdulmdllufvfvf")
    public suspend fun expeditedRollout(`value`: DefaultRolloutSpecificationExpeditedRolloutArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.expeditedRollout = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lcunkblhwauudlju")
    public suspend
    fun expeditedRollout(argument: suspend DefaultRolloutSpecificationExpeditedRolloutArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationExpeditedRolloutArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.expeditedRollout = mapped
    }

    /**
     * @param value
     */
    @JvmName("tmtqhfasfqgpbgia")
    public suspend fun highTraffic(`value`: DefaultRolloutSpecificationHighTrafficArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.highTraffic = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lreabqhycblchmuc")
    public suspend
    fun highTraffic(argument: suspend DefaultRolloutSpecificationHighTrafficArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationHighTrafficArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.highTraffic = mapped
    }

    /**
     * @param value
     */
    @JvmName("nfduivudqfwggrmx")
    public suspend fun lowTraffic(`value`: DefaultRolloutSpecificationLowTrafficArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lowTraffic = mapped
    }

    /**
     * @param argument
     */
    @JvmName("aptdsftjojvaenns")
    public suspend
    fun lowTraffic(argument: suspend DefaultRolloutSpecificationLowTrafficArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationLowTrafficArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.lowTraffic = mapped
    }

    /**
     * @param value
     */
    @JvmName("vrmajmceopyxomkn")
    public suspend fun mediumTraffic(`value`: DefaultRolloutSpecificationMediumTrafficArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mediumTraffic = mapped
    }

    /**
     * @param argument
     */
    @JvmName("etsedynjdxddesmo")
    public suspend
    fun mediumTraffic(argument: suspend DefaultRolloutSpecificationMediumTrafficArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationMediumTrafficArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.mediumTraffic = mapped
    }

    /**
     * @param value
     */
    @JvmName("bkcrforkvvhuikme")
    public suspend
    fun providerRegistration(`value`: DefaultRolloutSpecificationProviderRegistrationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerRegistration = mapped
    }

    /**
     * @param argument
     */
    @JvmName("udkpsgqldcnhuaoq")
    public suspend
    fun providerRegistration(argument: suspend DefaultRolloutSpecificationProviderRegistrationArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationProviderRegistrationArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.providerRegistration = mapped
    }

    /**
     * @param value
     */
    @JvmName("tqherfgrdssytrxy")
    public suspend fun resourceTypeRegistrations(`value`: List<ResourceTypeRegistrationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qdjqdasruihvbesg")
    public suspend
    fun resourceTypeRegistrations(argument: List<suspend ResourceTypeRegistrationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceTypeRegistrationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ifrcmruxlqqkweih")
    public suspend fun resourceTypeRegistrations(
        vararg
        argument: suspend ResourceTypeRegistrationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceTypeRegistrationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param argument
     */
    @JvmName("manjtowrvurqmivg")
    public suspend
    fun resourceTypeRegistrations(argument: suspend ResourceTypeRegistrationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceTypeRegistrationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param values
     */
    @JvmName("kvtfngiurxwhwepu")
    public suspend fun resourceTypeRegistrations(vararg values: ResourceTypeRegistrationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceTypeRegistrations = mapped
    }

    /**
     * @param value
     */
    @JvmName("lfwsjrfaclrjjiax")
    public suspend
    fun restOfTheWorldGroupOne(`value`: DefaultRolloutSpecificationRestOfTheWorldGroupOneArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.restOfTheWorldGroupOne = mapped
    }

    /**
     * @param argument
     */
    @JvmName("cohtdiiladqndixp")
    public suspend
    fun restOfTheWorldGroupOne(argument: suspend DefaultRolloutSpecificationRestOfTheWorldGroupOneArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationRestOfTheWorldGroupOneArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.restOfTheWorldGroupOne = mapped
    }

    /**
     * @param value
     */
    @JvmName("wusliovtmiibyukq")
    public suspend
    fun restOfTheWorldGroupTwo(`value`: DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.restOfTheWorldGroupTwo = mapped
    }

    /**
     * @param argument
     */
    @JvmName("xmbvrmeqydiaygpt")
    public suspend
    fun restOfTheWorldGroupTwo(argument: suspend DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultRolloutSpecificationRestOfTheWorldGroupTwoArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.restOfTheWorldGroupTwo = mapped
    }

    internal fun build(): DefaultRolloutPropertiesSpecificationArgs =
        DefaultRolloutPropertiesSpecificationArgs(
            canary = canary,
            expeditedRollout = expeditedRollout,
            highTraffic = highTraffic,
            lowTraffic = lowTraffic,
            mediumTraffic = mediumTraffic,
            providerRegistration = providerRegistration,
            resourceTypeRegistrations = resourceTypeRegistrations,
            restOfTheWorldGroupOne = restOfTheWorldGroupOne,
            restOfTheWorldGroupTwo = restOfTheWorldGroupTwo,
        )
}
